summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorshennetsind <ind@henn.et>2013-11-30 14:44:56 -0200
committershennetsind <ind@henn.et>2013-11-30 14:44:56 -0200
commit4e20f139fa7d0ebd6de30fde9b91ec5e235981d2 (patch)
treec42b4af0c8a7be63ef7ff7fc56fcfd017e982cd1
parent6fc1cae2088dd9f450e15728ca4bf4a82fcb8070 (diff)
parentc952fe0da69ebd5371004d6737a4e2e54859b9b0 (diff)
downloadhercules-4e20f139fa7d0ebd6de30fde9b91ec5e235981d2.tar.gz
hercules-4e20f139fa7d0ebd6de30fde9b91ec5e235981d2.tar.bz2
hercules-4e20f139fa7d0ebd6de30fde9b91ec5e235981d2.tar.xz
hercules-4e20f139fa7d0ebd6de30fde9b91ec5e235981d2.zip
Merge branch 'master' of https://github.com/HerculesWS/Hercules
-rw-r--r--conf/battle/battle.conf1
-rw-r--r--conf/messages.conf4
-rw-r--r--db/re/item_db.conf120
-rw-r--r--db/re/job_db1.txt5
-rw-r--r--npc/custom/healer.txt17
-rw-r--r--npc/quests/quests_moscovia.txt12
-rw-r--r--sql-files/item_db_re.sql120
-rw-r--r--src/char/char.c1
-rw-r--r--src/char/inter.c5
-rw-r--r--src/map/mob.c2
-rw-r--r--src/map/pc.c9
11 files changed, 153 insertions, 143 deletions
diff --git a/conf/battle/battle.conf b/conf/battle/battle.conf
index 70062a16e..5b72f5ff9 100644
--- a/conf/battle/battle.conf
+++ b/conf/battle/battle.conf
@@ -54,6 +54,7 @@ player_damage_delay_rate: 100
undead_detect_type: 0
// Does HP recover if hit by an attribute that's same as your own? (Note 1)
+// (Will not work in Renewal)
attribute_recover: no
// What is the minimum and maximum hitrate of normal attacks?
diff --git a/conf/messages.conf b/conf/messages.conf
index aae0596af..ba63dc73a 100644
--- a/conf/messages.conf
+++ b/conf/messages.conf
@@ -621,7 +621,8 @@
652: Expanded Super Baby
653: Kagerou
654: Oboro
-655: Unknown Job
+655: Rebellion
+656: Unknown Job
// MvP Tomb
// Added here so it can be easily translated
@@ -667,7 +668,6 @@
691: Sura T
692: Genetic T
693: Shadow Chaser T
-694: Rebellion
//------------------------------------
diff --git a/db/re/item_db.conf b/db/re/item_db.conf
index 727fb72a0..a67494ee0 100644
--- a/db/re/item_db.conf
+++ b/db/re/item_db.conf
@@ -65879,7 +65879,7 @@ item_db: (
AegisName: "Str_Dish01"
Name: "Fried Grasshopper Legs"
Type: 0
- Buy: 0
+ Buy: 2000
Weight: 60
Upper: 63
Script: <"
@@ -65892,7 +65892,7 @@ item_db: (
AegisName: "Str_Dish02"
Name: "Seasoned Sticky Webfoot"
Type: 0
- Buy: 0
+ Buy: 4000
Weight: 500
Upper: 63
Script: <"
@@ -65905,7 +65905,7 @@ item_db: (
AegisName: "Str_Dish03"
Name: "Bomber Steak"
Type: 0
- Buy: 0
+ Buy: 6000
Weight: 500
Upper: 63
Script: <"
@@ -65918,7 +65918,7 @@ item_db: (
AegisName: "Str_Dish04"
Name: "Herb Marinade Beef"
Type: 0
- Buy: 0
+ Buy: 8000
Weight: 500
Upper: 63
Script: <"
@@ -65931,7 +65931,7 @@ item_db: (
AegisName: "Str_Dish05"
Name: "Lutie Lady's Pancake"
Type: 0
- Buy: 0
+ Buy: 10000
Weight: 500
Upper: 63
Script: <"
@@ -65944,7 +65944,7 @@ item_db: (
AegisName: "Int_Dish01"
Name: "Grape Juice Herbal Tea"
Type: 0
- Buy: 0
+ Buy: 2000
Weight: 100
Upper: 63
Script: <"
@@ -65957,7 +65957,7 @@ item_db: (
AegisName: "Int_Dish02"
Name: "Autumn Red Tea"
Type: 0
- Buy: 0
+ Buy: 4000
Weight: 500
Upper: 63
Script: <"
@@ -65970,7 +65970,7 @@ item_db: (
AegisName: "Int_Dish03"
Name: "Honey Herbal Tea"
Type: 0
- Buy: 0
+ Buy: 6000
Weight: 500
Upper: 63
Script: <"
@@ -65983,7 +65983,7 @@ item_db: (
AegisName: "Int_Dish04"
Name: "Morroc Fruit Wine"
Type: 0
- Buy: 0
+ Buy: 8000
Weight: 300
Upper: 63
Script: <"
@@ -65996,7 +65996,7 @@ item_db: (
AegisName: "Int_Dish05"
Name: "Mastela Fruit Wine"
Type: 0
- Buy: 0
+ Buy: 10000
Weight: 400
Upper: 63
Script: <"
@@ -66009,7 +66009,7 @@ item_db: (
AegisName: "Vit_Dish01"
Name: "Steamed Crab Nippers"
Type: 0
- Buy: 0
+ Buy: 2000
Weight: 100
Upper: 63
Script: <"
@@ -66022,7 +66022,7 @@ item_db: (
AegisName: "Vit_Dish02"
Name: "Assorted Seafood"
Type: 0
- Buy: 0
+ Buy: 4000
Weight: 200
Upper: 63
Script: <"
@@ -66035,7 +66035,7 @@ item_db: (
AegisName: "Vit_Dish03"
Name: "Clam Soup"
Type: 0
- Buy: 0
+ Buy: 6000
Weight: 300
Upper: 63
Script: <"
@@ -66048,7 +66048,7 @@ item_db: (
AegisName: "Vit_Dish04"
Name: "Seasoned Jellyfish"
Type: 0
- Buy: 0
+ Buy: 8000
Weight: 500
Upper: 63
Script: <"
@@ -66061,7 +66061,7 @@ item_db: (
AegisName: "Vit_Dish05"
Name: "Spicy Fried Bao"
Type: 0
- Buy: 0
+ Buy: 10000
Weight: 800
Upper: 63
Script: <"
@@ -66074,7 +66074,7 @@ item_db: (
AegisName: "Agi_Dish01"
Name: "Frog Egg Squid Ink Soup"
Type: 0
- Buy: 0
+ Buy: 2000
Weight: 100
Upper: 63
Script: <"
@@ -66087,7 +66087,7 @@ item_db: (
AegisName: "Agi_Dish02"
Name: "Smooth Noodle"
Type: 0
- Buy: 0
+ Buy: 4000
Weight: 100
Upper: 63
Script: <"
@@ -66100,7 +66100,7 @@ item_db: (
AegisName: "Agi_Dish03"
Name: "Tentacle Cheese Gratin"
Type: 0
- Buy: 0
+ Buy: 6000
Weight: 500
Upper: 63
Script: <"
@@ -66113,7 +66113,7 @@ item_db: (
AegisName: "Agi_Dish04"
Name: "Lutie Cold Noodle"
Type: 0
- Buy: 0
+ Buy: 8000
Weight: 400
Upper: 63
Script: <"
@@ -66126,7 +66126,7 @@ item_db: (
AegisName: "Agi_Dish05"
Name: "Steamed Bat Wing in Pumpkin"
Type: 0
- Buy: 0
+ Buy: 10000
Weight: 500
Upper: 63
Script: <"
@@ -66139,7 +66139,7 @@ item_db: (
AegisName: "Dex_Dish01"
Name: "Honey Grape Juice"
Type: 0
- Buy: 0
+ Buy: 2000
Weight: 100
Upper: 63
Script: <"
@@ -66152,7 +66152,7 @@ item_db: (
AegisName: "Dex_Dish02"
Name: "Chocolate Mousse Cake"
Type: 0
- Buy: 0
+ Buy: 4000
Weight: 200
Upper: 63
Script: <"
@@ -66165,7 +66165,7 @@ item_db: (
AegisName: "Dex_Dish03"
Name: "Fruit Mix"
Type: 0
- Buy: 0
+ Buy: 6000
Weight: 200
Upper: 63
Script: <"
@@ -66178,7 +66178,7 @@ item_db: (
AegisName: "Dex_Dish04"
Name: "Cream Sandwich"
Type: 0
- Buy: 0
+ Buy: 8000
Weight: 500
Upper: 63
Script: <"
@@ -66191,7 +66191,7 @@ item_db: (
AegisName: "Dex_Dish05"
Name: "Green Salad"
Type: 0
- Buy: 0
+ Buy: 10000
Weight: 200
Upper: 63
Script: <"
@@ -66204,7 +66204,7 @@ item_db: (
AegisName: "Luk_Dish01"
Name: "Fried Monkey Tails"
Type: 0
- Buy: 0
+ Buy: 2000
Weight: 60
Upper: 63
Script: <"
@@ -66217,7 +66217,7 @@ item_db: (
AegisName: "Luk_Dish02"
Name: "Mixed Juice"
Type: 0
- Buy: 0
+ Buy: 4000
Weight: 200
Upper: 63
Script: <"
@@ -66230,7 +66230,7 @@ item_db: (
AegisName: "Luk_Dish03"
Name: "Fried Sweet Potato"
Type: 0
- Buy: 0
+ Buy: 6000
Weight: 500
Upper: 63
Script: <"
@@ -66243,7 +66243,7 @@ item_db: (
AegisName: "Luk_Dish04"
Name: "Steamed Ancient Lips"
Type: 0
- Buy: 0
+ Buy: 8000
Weight: 500
Upper: 63
Script: <"
@@ -66256,7 +66256,7 @@ item_db: (
AegisName: "Luk_Dish05"
Name: "Fried Scorpion Tails"
Type: 0
- Buy: 0
+ Buy: 10000
Weight: 400
Upper: 63
Script: <"
@@ -66269,7 +66269,7 @@ item_db: (
AegisName: "Str_Dish06"
Name: "Shiny Marinade Beef"
Type: 0
- Buy: 0
+ Buy: 20000
Weight: 800
Upper: 63
Script: <"
@@ -66282,7 +66282,7 @@ item_db: (
AegisName: "Str_Dish07"
Name: "Whole Roast"
Type: 0
- Buy: 0
+ Buy: 40000
Weight: 1000
Upper: 63
Script: <"
@@ -66295,7 +66295,7 @@ item_db: (
AegisName: "Str_Dish08"
Name: "Bearfoot Special"
Type: 0
- Buy: 0
+ Buy: 60000
Weight: 100
Upper: 63
Script: <"
@@ -66308,7 +66308,7 @@ item_db: (
AegisName: "Str_Dish09"
Name: "Tendon Satay"
Type: 0
- Buy: 0
+ Buy: 80000
Weight: 1000
Upper: 63
Script: <"
@@ -66321,7 +66321,7 @@ item_db: (
AegisName: "Str_Dish10"
Name: "Steamed Tongue"
Type: 0
- Buy: 0
+ Buy: 100000
Weight: 1000
Upper: 63
Script: <"
@@ -66334,7 +66334,7 @@ item_db: (
AegisName: "Int_Dish06"
Name: "Red Mushroom Wine"
Type: 0
- Buy: 0
+ Buy: 20000
Weight: 300
Upper: 63
Script: <"
@@ -66347,7 +66347,7 @@ item_db: (
AegisName: "Int_Dish07"
Name: "Special Royal Jelly Herbal Tea"
Type: 0
- Buy: 0
+ Buy: 40000
Weight: 800
Upper: 63
Script: <"
@@ -66360,7 +66360,7 @@ item_db: (
AegisName: "Int_Dish08"
Name: "Royal Family Tea"
Type: 0
- Buy: 0
+ Buy: 60000
Weight: 100
Upper: 63
Script: <"
@@ -66373,7 +66373,7 @@ item_db: (
AegisName: "Int_Dish09"
Name: "Tristram 12"
Type: 0
- Buy: 0
+ Buy: 80000
Weight: 1000
Upper: 63
Script: <"
@@ -66386,7 +66386,7 @@ item_db: (
AegisName: "Int_Dish10"
Name: "Dragon Breath Cocktail"
Type: 0
- Buy: 0
+ Buy: 100000
Weight: 1000
Upper: 63
Script: <"
@@ -66399,7 +66399,7 @@ item_db: (
AegisName: "Vit_Dish06"
Name: "Awfully Bitter Bracer"
Type: 0
- Buy: 0
+ Buy: 20000
Weight: 500
Upper: 63
Script: <"
@@ -66412,7 +66412,7 @@ item_db: (
AegisName: "Vit_Dish07"
Name: "Sumptuous Feast"
Type: 0
- Buy: 0
+ Buy: 40000
Weight: 400
Upper: 63
Script: <"
@@ -66425,7 +66425,7 @@ item_db: (
AegisName: "Vit_Dish08"
Name: "Giant Burito"
Type: 0
- Buy: 0
+ Buy: 60000
Weight: 100
Upper: 63
Script: <"
@@ -66438,7 +66438,7 @@ item_db: (
AegisName: "Vit_Dish09"
Name: "Ascending Dragon Soup"
Type: 0
- Buy: 0
+ Buy: 80000
Weight: 1000
Upper: 63
Script: <"
@@ -66451,7 +66451,7 @@ item_db: (
AegisName: "Vit_Dish10"
Name: "Immortal Stew"
Type: 0
- Buy: 0
+ Buy: 100000
Weight: 1000
Upper: 63
Script: <"
@@ -66464,7 +66464,7 @@ item_db: (
AegisName: "Agi_Dish06"
Name: "Chile Shrimp Gratin"
Type: 0
- Buy: 0
+ Buy: 20000
Weight: 800
Upper: 63
Script: <"
@@ -66477,7 +66477,7 @@ item_db: (
AegisName: "Agi_Dish07"
Name: "Steamed Alligator with Vegetable"
Type: 0
- Buy: 0
+ Buy: 40000
Weight: 800
Upper: 63
Script: <"
@@ -66490,7 +66490,7 @@ item_db: (
AegisName: "Agi_Dish08"
Name: "Incredibly Spicy Curry"
Type: 0
- Buy: 0
+ Buy: 60000
Weight: 100
Upper: 63
Script: <"
@@ -66503,7 +66503,7 @@ item_db: (
AegisName: "Agi_Dish09"
Name: "Special Meat Stew"
Type: 0
- Buy: 0
+ Buy: 80000
Weight: 1000
Upper: 63
Script: <"
@@ -66516,7 +66516,7 @@ item_db: (
AegisName: "Agi_Dish10"
Name: "Steamed Desert Scorpions"
Type: 0
- Buy: 0
+ Buy: 100000
Weight: 1000
Upper: 63
Script: <"
@@ -66529,7 +66529,7 @@ item_db: (
AegisName: "Dex_Dish06"
Name: "Peach Cake"
Type: 0
- Buy: 0
+ Buy: 20000
Weight: 800
Upper: 63
Script: <"
@@ -66542,7 +66542,7 @@ item_db: (
AegisName: "Dex_Dish07"
Name: "Soul Haunted Bread"
Type: 0
- Buy: 0
+ Buy: 40000
Weight: 800
Upper: 63
Script: <"
@@ -66555,7 +66555,7 @@ item_db: (
AegisName: "Dex_Dish08"
Name: "Special Toast"
Type: 0
- Buy: 0
+ Buy: 60000
Weight: 100
Upper: 63
Script: <"
@@ -66568,7 +66568,7 @@ item_db: (
AegisName: "Dex_Dish09"
Name: "Heavenly Fruit Juice"
Type: 0
- Buy: 0
+ Buy: 80000
Weight: 500
Upper: 63
Script: <"
@@ -66581,7 +66581,7 @@ item_db: (
AegisName: "Dex_Dish10"
Name: "Hwergelmir's Tonic"
Type: 0
- Buy: 0
+ Buy: 100000
Weight: 1000
Upper: 63
Script: <"
@@ -66594,7 +66594,7 @@ item_db: (
AegisName: "Luk_Dish06"
Name: "Lucky Soup"
Type: 0
- Buy: 0
+ Buy: 20000
Weight: 300
Upper: 63
Script: <"
@@ -66607,7 +66607,7 @@ item_db: (
AegisName: "Luk_Dish07"
Name: "Assorted Shish Kebob"
Type: 0
- Buy: 0
+ Buy: 40000
Weight: 800
Upper: 63
Script: <"
@@ -66620,7 +66620,7 @@ item_db: (
AegisName: "Luk_Dish08"
Name: "Strawberry Flavored Rice Ball"
Type: 0
- Buy: 0
+ Buy: 60000
Weight: 100
Upper: 63
Script: <"
@@ -66633,7 +66633,7 @@ item_db: (
AegisName: "Luk_Dish09"
Name: "Blood Flavored Soda"
Type: 0
- Buy: 0
+ Buy: 80000
Weight: 1000
Upper: 63
Script: <"
@@ -66646,7 +66646,7 @@ item_db: (
AegisName: "Luk_Dish10"
Name: "Cooked Nine Tail's Tails"
Type: 0
- Buy: 0
+ Buy: 100000
Weight: 500
Upper: 63
Script: <"
diff --git a/db/re/job_db1.txt b/db/re/job_db1.txt
index ff175592a..abc9d2bb8 100644
--- a/db/re/job_db1.txt
+++ b/db/re/job_db1.txt
@@ -52,7 +52,7 @@
// Super Novice
23, 20000,0 ,500 ,100 ,440 ,590 ,610 ,2000 ,2000 ,2000 ,540 ,2000 ,540 ,540 ,690 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,690 ,540
// Gunslinger
-24, 28000,88 ,0 ,450 ,540 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,490 ,590 ,440 ,940 ,1040 ,2000 ,2000 ,600
+24, 28000,88 ,0 ,450 ,540 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,490 ,590 ,540 ,940 ,1040 ,2000 ,2000 ,600
// Ninja
25, 26000,80 ,0 ,515 ,440 ,470 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,590 ,2000 ,500
// Novice High
@@ -270,4 +270,5 @@
// Oboro
4212, 26000,80 , 0 ,515 ,400 ,500 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 , 750 ,2000 ,500
// Rebellion
-4215, 28000,88 , 0 ,450 ,540 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,490 ,590 ,440 ,940 ,1040 ,2000 ,2000 ,600
+
+4215, 28000,88 , 0 ,450 ,550 ,2000, 2000, 2000, 2000, 2000, 2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 ,2000 , 520 , 620 , 570 ,970 ,1070 ,2000 ,2000 ,600
diff --git a/npc/custom/healer.txt b/npc/custom/healer.txt
index e11e2a647..59d67b083 100644
--- a/npc/custom/healer.txt
+++ b/npc/custom/healer.txt
@@ -3,34 +3,35 @@
//===== By: ==================================================
//= Euphy
//===== Current Version: =====================================
-//= 1.1
+//= 1.2
//===== Description: =========================================
//= Basic healer script.
//===== Additional Comments: =================================
//= 1.0 Initial script.
//= 1.1 Aligned coordinates with @go.
+//= 1.2 Fix variables and character stuck at healing
//============================================================
- script Healer -1,{
- set .@price,0; // Zeny required for heal
- set .@Buffs,0; // Also buff players? (1: yes / 0: no)
- set .@Delay,0; // Heal delay, in seconds
+ .@price = 0; // Zeny required for heal
+ .@Buffs = 0; // Also buff players? (1: yes / 0: no)
+ .@Delay = 0; // Heal delay, in seconds
if (@HD > gettimetick(2)) end;
if (.@price) {
message strcharinfo(0),"Healing costs "+.@price+" Zeny.";
if (Zeny < .@price) end;
- if(select("^0055FFHeal^000000:^777777Cancel^000000") == 2) end;
- set Zeny, Zeny-.@price;
+ if(select("^0055FFHeal^000000:^777777Cancel^000000") == 2) close;
+ Zeny -= .@price;
}
specialeffect2 EF_HEAL2; percentheal 100,100;
if (.@Buffs) {
specialeffect2 EF_INCAGILITY; sc_start SC_INC_AGI,240000,10;
specialeffect2 EF_BLESSING; sc_start SC_BLESSING,240000,10;
}
- if (.@Delay) set @HD, gettimetick(2)+.@Delay;
- end;
+ if (.@Delay) @HD = gettimetick(2)+.@Delay;
+ close;
}
diff --git a/npc/quests/quests_moscovia.txt b/npc/quests/quests_moscovia.txt
index fd68f6663..a181a81d9 100644
--- a/npc/quests/quests_moscovia.txt
+++ b/npc/quests/quests_moscovia.txt
@@ -1484,7 +1484,7 @@ mosk_fild01,86,104,3 script Aged Stranger#npc 4_M_GUSLIMAN,{
mes "This is a traditional instrument";
mes "which comes from a faraway land of";
mes "the ancestors of Moscovia.";
- getitem 2707,1;
+ getitem GUSLI, 1;
set mos_whale_edq,35;
next;
mes "[Aged Stranger]";
@@ -1509,7 +1509,7 @@ mosk_fild01,86,104,3 script Aged Stranger#npc 4_M_GUSLIMAN,{
mes "Are you ready to learn the Gusli?";
mes "Please equip the Gusli.";
next;
- if (getequipid(EQI_ACC_L) || getequipid(EQI_ACC_R) == 2707) {
+ if (getequipid(EQI_ACC_L) == GUSLI || getequipid(EQI_ACC_R) == GUSLI) {
mes "[Aged Stranger]";
mes "Hm... Very well.";
mes "At first, look at me how I play,";
@@ -1552,7 +1552,7 @@ mosk_fild01,86,104,3 script Aged Stranger#npc 4_M_GUSLIMAN,{
mes "[Aged Stranger]";
mes "Are you ready to learn the Gusli?";
next;
- if (getequipid(EQI_ACC_L) || getequipid(EQI_ACC_R) == 2707) {
+ if (getequipid(EQI_ACC_L) == GUSLI || getequipid(EQI_ACC_R) == GUSLI) {
mes "[Aged Stranger]";
mes "Um... You did well.";
next;
@@ -2123,7 +2123,7 @@ mosk_in,131,92,3 script Csar Alexsay III#npc 4_M_RUSKING,{
mes "A Gooselri? Which only exists";
mes "in the whale island? Let's see.";
next;
- if (getequipid(EQI_ACC_L) || getequipid(EQI_ACC_R) == 2707 || countitem(2707) > 0) {
+ if (countitem(GUSLI) > 0) {
mes "[Csar Alexsay III]";
mes "Oh... Is this instrument... a Gooselri?";
next;
@@ -2233,7 +2233,7 @@ mosk_in,131,92,3 script Csar Alexsay III#npc 4_M_RUSKING,{
mes "something to satisfy me";
mes "at the whale island?";
next;
- if (getequipid(EQI_ACC_L) || getequipid(EQI_ACC_R) == 2707 || countitem(2707)) {
+ if (countitem(GUSLI) > 0) {
mes "[Csar Alexsay III]";
mes "Oh... Is this instrument... a Gooselri?";
next;
@@ -2478,7 +2478,7 @@ OnTouch:
mes "Stop by the whale island?";
next;
if(select("Go to Whale Island.:Stay put.") == 1) {
- if (getequipid(EQI_ACC_L) == 2707 || getequipid(EQI_ACC_R) == 2707) {
+ if (getequipid(EQI_ACC_L) == GUSLI || getequipid(EQI_ACC_R) == GUSLI) {
soundeffect "mos_gusli2.wav",0;
mes "-Slowly, your hands are on the";
mes "Gusli, and the playing starts...";
diff --git a/sql-files/item_db_re.sql b/sql-files/item_db_re.sql
index 6352dc61f..d8a5497cc 100644
--- a/sql-files/item_db_re.sql
+++ b/sql-files/item_db_re.sql
@@ -5324,66 +5324,66 @@ REPLACE INTO `item_db_re` VALUES ('12037','Lotto_Box03','Lotto Box 03','2','0','
REPLACE INTO `item_db_re` VALUES ('12038','Lotto_Box04','Lotto Box 04','2','0','0','20','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','getrandgroupitem 12038,1;','','');
REPLACE INTO `item_db_re` VALUES ('12039','Lotto_Box05','Lotto Box 05','2','0','0','20','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','getitem rand(7542,7546),1;','','');
REPLACE INTO `item_db_re` VALUES ('12040','Stone_Of_Intelligence_','Stone of Sage','2','100000','50000','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','homevolution;','','');
-REPLACE INTO `item_db_re` VALUES ('12041','Str_Dish01','Fried Grasshopper Legs','0','0','0','60','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,1; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12042','Str_Dish02','Seasoned Sticky Webfoot','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,2; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12043','Str_Dish03','Bomber Steak','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,3; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12044','Str_Dish04','Herb Marinade Beef','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,4; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12045','Str_Dish05','Lutie Lady\'s Pancake','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,5; percentheal 10,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12046','Int_Dish01','Grape Juice Herbal Tea','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,1; percentheal 0,5;','','');
-REPLACE INTO `item_db_re` VALUES ('12047','Int_Dish02','Autumn Red Tea','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,2; percentheal 0,5;','','');
-REPLACE INTO `item_db_re` VALUES ('12048','Int_Dish03','Honey Herbal Tea','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,3; percentheal 0,5;','','');
-REPLACE INTO `item_db_re` VALUES ('12049','Int_Dish04','Morroc Fruit Wine','0','0','0','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,4; percentheal 0,5;','','');
-REPLACE INTO `item_db_re` VALUES ('12050','Int_Dish05','Mastela Fruit Wine','0','0','0','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,5; percentheal 0,10;','','');
-REPLACE INTO `item_db_re` VALUES ('12051','Vit_Dish01','Steamed Crab Nippers','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,1; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12052','Vit_Dish02','Assorted Seafood','0','0','0','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,2; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12053','Vit_Dish03','Clam Soup','0','0','0','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,3; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12054','Vit_Dish04','Seasoned Jellyfish','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,4; percentheal 5,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12055','Vit_Dish05','Spicy Fried Bao','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,5; percentheal 10,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12056','Agi_Dish01','Frog Egg Squid Ink Soup','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,1; percentheal 3,1;','','');
-REPLACE INTO `item_db_re` VALUES ('12057','Agi_Dish02','Smooth Noodle','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,2; percentheal 3,1;','','');
-REPLACE INTO `item_db_re` VALUES ('12058','Agi_Dish03','Tentacle Cheese Gratin','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,3; percentheal 3,1;','','');
-REPLACE INTO `item_db_re` VALUES ('12059','Agi_Dish04','Lutie Cold Noodle','0','0','0','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,4; percentheal 3,1;','','');
-REPLACE INTO `item_db_re` VALUES ('12060','Agi_Dish05','Steamed Bat Wing in Pumpkin','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,5; percentheal 6,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12061','Dex_Dish01','Honey Grape Juice','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,1; percentheal 2,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12062','Dex_Dish02','Chocolate Mousse Cake','0','0','0','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,2; percentheal 2,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12063','Dex_Dish03','Fruit Mix','0','0','0','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,3; percentheal 2,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12064','Dex_Dish04','Cream Sandwich','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,4; percentheal 2,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12065','Dex_Dish05','Green Salad','0','0','0','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,5; percentheal 5,5;','','');
-REPLACE INTO `item_db_re` VALUES ('12066','Luk_Dish01','Fried Monkey Tails','0','0','0','60','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,1; percentheal 3,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12067','Luk_Dish02','Mixed Juice','0','0','0','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,2; percentheal 3,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12068','Luk_Dish03','Fried Sweet Potato','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,3; percentheal 4,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12069','Luk_Dish04','Steamed Ancient Lips','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,4; percentheal 4,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12070','Luk_Dish05','Fried Scorpion Tails','0','0','0','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,5; percentheal 5,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12071','Str_Dish06','Shiny Marinade Beef','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,6; percentheal 10,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12072','Str_Dish07','Whole Roast','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,7; percentheal 10,4;','','');
-REPLACE INTO `item_db_re` VALUES ('12073','Str_Dish08','Bearfoot Special','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,8; percentheal 15,6;','','');
-REPLACE INTO `item_db_re` VALUES ('12074','Str_Dish09','Tendon Satay','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,9; percentheal 15,8;','','');
-REPLACE INTO `item_db_re` VALUES ('12075','Str_Dish10','Steamed Tongue','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,10; percentheal 20,20;','','');
-REPLACE INTO `item_db_re` VALUES ('12076','Int_Dish06','Red Mushroom Wine','0','0','0','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,6; percentheal 2,10;','','');
-REPLACE INTO `item_db_re` VALUES ('12077','Int_Dish07','Special Royal Jelly Herbal Tea','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,7; percentheal 4,10;','','');
-REPLACE INTO `item_db_re` VALUES ('12078','Int_Dish08','Royal Family Tea','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,8; percentheal 6,10;','','');
-REPLACE INTO `item_db_re` VALUES ('12079','Int_Dish09','Tristram 12','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,9; percentheal 8,15;','','');
-REPLACE INTO `item_db_re` VALUES ('12080','Int_Dish10','Dragon Breath Cocktail','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,10; percentheal 10,20;','','');
-REPLACE INTO `item_db_re` VALUES ('12081','Vit_Dish06','Awfully Bitter Bracer','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,6; percentheal 13,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12082','Vit_Dish07','Sumptuous Feast','0','0','0','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,7; percentheal 16,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12083','Vit_Dish08','Giant Burito','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,8; percentheal 19,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12084','Vit_Dish09','Ascending Dragon Soup','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,9; percentheal 22,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12085','Vit_Dish10','Immortal Stew','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,10; percentheal 25,0;','','');
-REPLACE INTO `item_db_re` VALUES ('12086','Agi_Dish06','Chile Shrimp Gratin','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,6; percentheal 7,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12087','Agi_Dish07','Steamed Alligator with Vegetable','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,7; percentheal 8,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12088','Agi_Dish08','Incredibly Spicy Curry','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,8; percentheal 9,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12089','Agi_Dish09','Special Meat Stew','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,9; percentheal 10,2;','','');
-REPLACE INTO `item_db_re` VALUES ('12090','Agi_Dish10','Steamed Desert Scorpions','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,10; percentheal 15,5;','','');
-REPLACE INTO `item_db_re` VALUES ('12091','Dex_Dish06','Peach Cake','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,6; percentheal 5,6;','','');
-REPLACE INTO `item_db_re` VALUES ('12092','Dex_Dish07','Soul Haunted Bread','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,7; percentheal 5,7;','','');
-REPLACE INTO `item_db_re` VALUES ('12093','Dex_Dish08','Special Toast','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,8; percentheal 5,8;','','');
-REPLACE INTO `item_db_re` VALUES ('12094','Dex_Dish09','Heavenly Fruit Juice','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,9; percentheal 5,9;','','');
-REPLACE INTO `item_db_re` VALUES ('12095','Dex_Dish10','Hwergelmir\'s Tonic','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,10; percentheal 10,10;','','');
-REPLACE INTO `item_db_re` VALUES ('12096','Luk_Dish06','Lucky Soup','0','0','0','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,6; percentheal 6,3;','','');
-REPLACE INTO `item_db_re` VALUES ('12097','Luk_Dish07','Assorted Shish Kebob','0','0','0','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,7; percentheal 7,3;','','');
-REPLACE INTO `item_db_re` VALUES ('12098','Luk_Dish08','Strawberry Flavored Rice Ball','0','0','0','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,8; percentheal 9,3;','','');
-REPLACE INTO `item_db_re` VALUES ('12099','Luk_Dish09','Blood Flavored Soda','0','0','0','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,9; percentheal 10,4;','','');
-REPLACE INTO `item_db_re` VALUES ('12100','Luk_Dish10','Cooked Nine Tail\'s Tails','0','0','0','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,10; percentheal 14,8;','','');
+REPLACE INTO `item_db_re` VALUES ('12041','Str_Dish01','Fried Grasshopper Legs','0','2000','1000','60','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,1; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12042','Str_Dish02','Seasoned Sticky Webfoot','0','4000','2000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,2; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12043','Str_Dish03','Bomber Steak','0','6000','3000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,3; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12044','Str_Dish04','Herb Marinade Beef','0','8000','4000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,4; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12045','Str_Dish05','Lutie Lady\'s Pancake','0','10000','5000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,5; percentheal 10,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12046','Int_Dish01','Grape Juice Herbal Tea','0','2000','1000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,1; percentheal 0,5;','','');
+REPLACE INTO `item_db_re` VALUES ('12047','Int_Dish02','Autumn Red Tea','0','4000','2000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,2; percentheal 0,5;','','');
+REPLACE INTO `item_db_re` VALUES ('12048','Int_Dish03','Honey Herbal Tea','0','6000','3000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,3; percentheal 0,5;','','');
+REPLACE INTO `item_db_re` VALUES ('12049','Int_Dish04','Morroc Fruit Wine','0','8000','4000','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,4; percentheal 0,5;','','');
+REPLACE INTO `item_db_re` VALUES ('12050','Int_Dish05','Mastela Fruit Wine','0','10000','5000','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,5; percentheal 0,10;','','');
+REPLACE INTO `item_db_re` VALUES ('12051','Vit_Dish01','Steamed Crab Nippers','0','2000','1000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,1; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12052','Vit_Dish02','Assorted Seafood','0','4000','2000','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,2; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12053','Vit_Dish03','Clam Soup','0','6000','3000','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,3; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12054','Vit_Dish04','Seasoned Jellyfish','0','8000','4000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,4; percentheal 5,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12055','Vit_Dish05','Spicy Fried Bao','0','10000','5000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,5; percentheal 10,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12056','Agi_Dish01','Frog Egg Squid Ink Soup','0','2000','1000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,1; percentheal 3,1;','','');
+REPLACE INTO `item_db_re` VALUES ('12057','Agi_Dish02','Smooth Noodle','0','4000','2000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,2; percentheal 3,1;','','');
+REPLACE INTO `item_db_re` VALUES ('12058','Agi_Dish03','Tentacle Cheese Gratin','0','6000','3000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,3; percentheal 3,1;','','');
+REPLACE INTO `item_db_re` VALUES ('12059','Agi_Dish04','Lutie Cold Noodle','0','8000','4000','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,4; percentheal 3,1;','','');
+REPLACE INTO `item_db_re` VALUES ('12060','Agi_Dish05','Steamed Bat Wing in Pumpkin','0','10000','5000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,5; percentheal 6,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12061','Dex_Dish01','Honey Grape Juice','0','2000','1000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,1; percentheal 2,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12062','Dex_Dish02','Chocolate Mousse Cake','0','4000','2000','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,2; percentheal 2,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12063','Dex_Dish03','Fruit Mix','0','6000','3000','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,3; percentheal 2,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12064','Dex_Dish04','Cream Sandwich','0','8000','4000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,4; percentheal 2,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12065','Dex_Dish05','Green Salad','0','10000','5000','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,5; percentheal 5,5;','','');
+REPLACE INTO `item_db_re` VALUES ('12066','Luk_Dish01','Fried Monkey Tails','0','2000','1000','60','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,1; percentheal 3,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12067','Luk_Dish02','Mixed Juice','0','4000','2000','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,2; percentheal 3,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12068','Luk_Dish03','Fried Sweet Potato','0','6000','3000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,3; percentheal 4,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12069','Luk_Dish04','Steamed Ancient Lips','0','8000','4000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,4; percentheal 4,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12070','Luk_Dish05','Fried Scorpion Tails','0','10000','5000','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,5; percentheal 5,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12071','Str_Dish06','Shiny Marinade Beef','0','20000','10000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,6; percentheal 10,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12072','Str_Dish07','Whole Roast','0','40000','20000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,7; percentheal 10,4;','','');
+REPLACE INTO `item_db_re` VALUES ('12073','Str_Dish08','Bearfoot Special','0','60000','30000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,8; percentheal 15,6;','','');
+REPLACE INTO `item_db_re` VALUES ('12074','Str_Dish09','Tendon Satay','0','80000','40000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,9; percentheal 15,8;','','');
+REPLACE INTO `item_db_re` VALUES ('12075','Str_Dish10','Steamed Tongue','0','100000','50000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_STR,1200000,10; percentheal 20,20;','','');
+REPLACE INTO `item_db_re` VALUES ('12076','Int_Dish06','Red Mushroom Wine','0','20000','10000','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,6; percentheal 2,10;','','');
+REPLACE INTO `item_db_re` VALUES ('12077','Int_Dish07','Special Royal Jelly Herbal Tea','0','40000','20000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,7; percentheal 4,10;','','');
+REPLACE INTO `item_db_re` VALUES ('12078','Int_Dish08','Royal Family Tea','0','60000','30000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,8; percentheal 6,10;','','');
+REPLACE INTO `item_db_re` VALUES ('12079','Int_Dish09','Tristram 12','0','80000','40000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,9; percentheal 8,15;','','');
+REPLACE INTO `item_db_re` VALUES ('12080','Int_Dish10','Dragon Breath Cocktail','0','100000','50000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_INT,1200000,10; percentheal 10,20;','','');
+REPLACE INTO `item_db_re` VALUES ('12081','Vit_Dish06','Awfully Bitter Bracer','0','20000','10000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,6; percentheal 13,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12082','Vit_Dish07','Sumptuous Feast','0','40000','20000','400','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,7; percentheal 16,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12083','Vit_Dish08','Giant Burito','0','60000','30000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,8; percentheal 19,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12084','Vit_Dish09','Ascending Dragon Soup','0','80000','40000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,9; percentheal 22,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12085','Vit_Dish10','Immortal Stew','0','100000','50000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_VIT,1200000,10; percentheal 25,0;','','');
+REPLACE INTO `item_db_re` VALUES ('12086','Agi_Dish06','Chile Shrimp Gratin','0','20000','10000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,6; percentheal 7,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12087','Agi_Dish07','Steamed Alligator with Vegetable','0','40000','20000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,7; percentheal 8,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12088','Agi_Dish08','Incredibly Spicy Curry','0','60000','30000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,8; percentheal 9,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12089','Agi_Dish09','Special Meat Stew','0','80000','40000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,9; percentheal 10,2;','','');
+REPLACE INTO `item_db_re` VALUES ('12090','Agi_Dish10','Steamed Desert Scorpions','0','100000','50000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_AGI,1200000,10; percentheal 15,5;','','');
+REPLACE INTO `item_db_re` VALUES ('12091','Dex_Dish06','Peach Cake','0','20000','10000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,6; percentheal 5,6;','','');
+REPLACE INTO `item_db_re` VALUES ('12092','Dex_Dish07','Soul Haunted Bread','0','40000','20000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,7; percentheal 5,7;','','');
+REPLACE INTO `item_db_re` VALUES ('12093','Dex_Dish08','Special Toast','0','60000','30000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,8; percentheal 5,8;','','');
+REPLACE INTO `item_db_re` VALUES ('12094','Dex_Dish09','Heavenly Fruit Juice','0','80000','40000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,9; percentheal 5,9;','','');
+REPLACE INTO `item_db_re` VALUES ('12095','Dex_Dish10','Hwergelmir\'s Tonic','0','100000','50000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_DEX,1200000,10; percentheal 10,10;','','');
+REPLACE INTO `item_db_re` VALUES ('12096','Luk_Dish06','Lucky Soup','0','20000','10000','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,6; percentheal 6,3;','','');
+REPLACE INTO `item_db_re` VALUES ('12097','Luk_Dish07','Assorted Shish Kebob','0','40000','20000','800','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,7; percentheal 7,3;','','');
+REPLACE INTO `item_db_re` VALUES ('12098','Luk_Dish08','Strawberry Flavored Rice Ball','0','60000','30000','100','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,8; percentheal 9,3;','','');
+REPLACE INTO `item_db_re` VALUES ('12099','Luk_Dish09','Blood Flavored Soda','0','80000','40000','1000','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,9; percentheal 10,4;','','');
+REPLACE INTO `item_db_re` VALUES ('12100','Luk_Dish10','Cooked Nine Tail\'s Tails','0','100000','50000','500','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','sc_start SC_FOOD_LUK,1200000,10; percentheal 14,8;','','');
REPLACE INTO `item_db_re` VALUES ('12101','Citron','Citron','0','20','10','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','','','');
REPLACE INTO `item_db_re` VALUES ('12102','Meat_Skewer','Grilled Skewer','0','20','10','300','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','','','');
REPLACE INTO `item_db_re` VALUES ('12103','Bloody_Dead_Branch','Bloody Branch','2','10000','5000','200','0','0','0','0','0','4294967295','63','2','0','0','0',NULL,'0','0','0','monster \"this\",-1,-1,\"--ja--\",-3,1,\"\";','','');
diff --git a/src/char/char.c b/src/char/char.c
index 63b47cfcf..e58fc9eef 100644
--- a/src/char/char.c
+++ b/src/char/char.c
@@ -1278,6 +1278,7 @@ int mmo_char_fromsql(int char_id, struct mmo_charstatus* p, bool load_everything
StrBuf->Printf(&buf, ", `card%d`", j);
StrBuf->Printf(&buf, " FROM `%s` WHERE `char_id`=? LIMIT %d", cart_db, MAX_CART);
+ memset(&tmp_item, 0, sizeof(tmp_item));
if( SQL_ERROR == SQL->StmtPrepareStr(stmt, StrBuf->Value(&buf))
|| SQL_ERROR == SQL->StmtBindParam(stmt, 0, SQLDT_INT, &char_id, 0)
|| SQL_ERROR == SQL->StmtExecute(stmt)
diff --git a/src/char/inter.c b/src/char/inter.c
index b213f1608..771b51602 100644
--- a/src/char/inter.c
+++ b/src/char/inter.c
@@ -341,8 +341,11 @@ const char* job_name(int class_) {
case JOB_OBORO:
return msg_txt(653 - JOB_KAGEROU+class_);
- default:
+ case JOB_REBELLION:
return msg_txt(655);
+
+ default:
+ return msg_txt(656);
}
}
diff --git a/src/map/mob.c b/src/map/mob.c
index 02c263bd3..16c33b552 100644
--- a/src/map/mob.c
+++ b/src/map/mob.c
@@ -2447,7 +2447,6 @@ int mob_dead(struct mob_data *md, struct block_list *src, int type) {
if(mvp_sd && md->db->mexp > 0 && !md->special_state.ai) {
int log_mvp[2] = {0};
unsigned int mexp;
- struct item item;
double exp;
//mapflag: noexp check [Lorky]
@@ -2470,6 +2469,7 @@ int mob_dead(struct mob_data *md, struct block_list *src, int type) {
/* pose them randomly in the list -- so on 100% drop servers it wont always drop the same item */
int mdrop_id[MAX_MVP_DROP];
int mdrop_p[MAX_MVP_DROP];
+ struct item item;
memset(&mdrop_id,0,MAX_MVP_DROP*sizeof(int));
diff --git a/src/map/pc.c b/src/map/pc.c
index 84880c24d..feca11758 100644
--- a/src/map/pc.c
+++ b/src/map/pc.c
@@ -4000,9 +4000,11 @@ int pc_additem(struct map_session_data *sd,struct item *item_data,int amount,e_l
return 4;
memcpy(&sd->status.inventory[i], item_data, sizeof(sd->status.inventory[0]));
// clear equips field first, just in case
if( item_data->equip )
sd->status.inventory[i].equip = 0;
+ if( item_data->favorite )
+ sd->status.inventory[i].favorite = 0;
sd->status.inventory[i].amount = amount;
sd->inventory_data[i] = data;
@@ -5760,11 +5762,12 @@ const char* job_name(int class_)
case JOB_KAGEROU:
case JOB_OBORO:
return msg_txt(653 - JOB_KAGEROU+class_);
+
case JOB_REBELLION:
- return msg_txt(694);
+ return msg_txt(655);
default:
- return msg_txt(655);
+ return msg_txt(656);
}
}
@@ -4000,9 +4000,11 @@ int pc_additem(struct map_session_data *sd,struct item *item_data,int amount,e_l
return 4;
memcpy(&sd->status.inventory[i], item_data, sizeof(sd->status.inventory[0]));
- // clear equips field first, just in case
+ // clear equip and favorite fields first, just in case
if( item_data->equip )
sd->status.inventory[i].equip = 0;